@@ -18,10 +18,12 @@
 */
 
 #include "Models/StateSpace/StateModels/DynamicRegressionStateModel.hpp"
+#include "Models/StateSpace/DynamicInterceptRegression.hpp"
 #include "cpputil/math_utils.hpp"
 #include "distributions.hpp"
 #include "stats/moments.hpp"
 
+
 namespace BOOM {
   namespace {
     typedef DynamicRegressionStateModel DRSM;
@@ -143,7 +145,7 @@ namespace BOOM {
     return new DynamicRegressionStateModel(*this);
   }
 
-  void DRSM::set_xnames(const std::vector<string> &xnames) {
+  void DRSM::set_xnames(const std::vector<std::string> &xnames) {
     if (xnames.size() != state_dimension()) {
       std::ostringstream err;
       err << "Error in DRSM::set_xnames." << endl
@@ -154,7 +156,7 @@ namespace BOOM {
     xnames_ = xnames;
   }
 
-  const std::vector<string> &DRSM::xnames() const { return xnames_; }
+  const std::vector<std::string> &DRSM::xnames() const { return xnames_; }
 
   void DRSM::clear_data() {
     for (int i = 0; i < coefficient_transition_model_.size(); ++i) {
@@ -163,8 +165,7 @@ namespace BOOM {
   }
 
   void DRSM::observe_state(const ConstVectorView &then,
-                           const ConstVectorView &now, int time_now,
-                           ScalarStateSpaceModelBase *) {
+                           const ConstVectorView &now, int time_now) {
     check_size(then.size());
     check_size(now.size());
     for (int i = 0; i < then.size(); ++i) {
@@ -173,12 +174,6 @@ namespace BOOM {
     }
   }
 
-  void DRSM::observe_dynamic_intercept_regression_state(
-      const ConstVectorView &then, const ConstVectorView &now, int time_now,
-      DynamicInterceptRegressionModel *) {
-    observe_state(then, now, time_now, nullptr);
-  }
-
   void DRSM::observe_initial_state(const ConstVectorView &state) {}
 
   uint DRSM::state_dimension() const { return xdim_; }
@@ -220,18 +215,6 @@ namespace BOOM {
     return sparse_predictor_vectors_[t];
   }
 
-  Ptr<SparseMatrixBlock>
-  DRSM::dynamic_intercept_regression_observation_coefficients(
-      int t, const StateSpace::MultiplexedData &data_point) const {
-    Ptr<DenseMatrix> ans = sparse_predictor_matrices_[t];
-    if (data_point.total_sample_size() != ans->nrow()) {
-      report_error(
-          "Mismatch between model data and "
-          "DynamicRegressionStateModel data.");
-    }
-    return ans;
-  }
-
   Vector DRSM::initial_state_mean() const { return initial_state_mean_; }
 
   void DRSM::set_initial_state_mean(const Vector &mu) {
@@ -327,4 +310,19 @@ namespace BOOM {
     }
   }
 
+
+  // Ptr<SparseMatrixBlock>
+  // DRSM::dynamic_intercept_regression_observation_coefficients(
+  //     int t, const StateSpace::TimeSeriesRegressionData &data_point) const {
+  //   Ptr<DenseMatrix> ans = sparse_predictor_matrices_[t];
+  //   if (data_point.sample_size() != ans->nrow()) {
+  //     report_error(
+  //         "Mismatch between model data and "
+  //         "DynamicRegressionStateModel data.");
+  //   }
+  //   return ans;
+  // }
+
+
+  
 }  // namespace BOOM
