@@ -16,7 +16,7 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 #include <thread>
-#include <r_interface/determine_nthreads.hpp>
+#include "r_interface/determine_nthreads.hpp"
 #include "cpputil/report_error.hpp"
 
 namespace BOOM {
